==> kjy-center-api-1.1.4-sources.jar: cn/com/duiba/kjy/api/enums/seller/SellerFromEnum.java <==
package cn.com.duiba.kjy.api.enums.seller;

import java.util.Arrays;
import java.util.List;

/**
 * 销售员来源定义
 * @author zhanghuifeng
 * date 2019-06-25-16:27
 */
public enum SellerFromEnum {

    /**
     * 销售来源场景
     */
    NORMAL("0", "一般途径"),
    POSTER_INVITE("1", "海报邀请(普通邀请)"),
    CARD("2", "文章、午报、晚报换名片邀请(普通邀请)"),
    SITE_SALE_QR("3", "会销扫码（会销邀请）"),
    OUR_INSIDE_RECOMMEND("4", "公司内部销售推荐（只用作绩效记录，不做其它业务用途）"),
    WEEKLY_PUBLICATION("5", "周报中关注客集集"),
    VISITOR_PAYMENT("6", "访客转化为付费用户"),
    NOVICE_TASK("7", "新手任务邀请"),
    ACTIVATE_CODE("45", "激活码"),
    WX_MP_BASE_AUTH("46", "小程序授权"),
    PC_OFFICIAL_WEBSITE("77","官网"),
    VIP_NOT_SUBSCRIBE_VIP_ACCOUNT_PAGE("123", "付费代理人未关注vip公众号弹层二维码"),
    VIP_NOT_SUBSCRIBE_VIP_ACCOUNT_PUSH("124", "代理人通过蓝号推送的VIP公众号图片关注VIP公众号"),
    DAILY_CHANGE_CARD("126", "早报换名片邀请(普通邀请)"),
    VIDEO_CHANGE_CARD("137", "视频换名片邀请(普通邀请)"),
    CARTOON_CHANGE_CARD("127", "动画换名片邀请(普通邀请)"),
    GAME_ANSWER_CHANGE_CARD("135", "小游戏换名片邀请(普通邀请)"),
    GAME_LOTTERY_CHANGE_CARD("136", "抽奖工具换名片邀请(普通邀请)"),
    OTHER_CHANGE_CARD("134", "其他内容页换名片邀请(普通邀请)"),
    DAILY_CHANGE_MYPOINT("143", "早报换我的观点(换成我的观点弹层)"),
    PRE_INSTALL("159","会员预设"),
    VIP_TRANSFET("164", "会员转移"),
    OPEN_USER("165","第三方公众号用户"),
    MORNING_POSTER("166", "早安海报扫码来源"),
    EVENING_POSTER("167", "晚安海报扫码来源"),
    GUIDE_MORNING_CLOCK("168", "用户引导-早安打卡"),
    GUIDE_EVENING_CLOCK("169", "用户引导-晚安打卡"),
    GUIDE_EVERYDAY_QUESTION("170", "用户引导-每日一问(已更新)"),
    LIVE_VISITOR_MAP_COMPANY_NAME_LIST("194", "直播访客匹配架构名单成为代理人"),
    TRY_USE_CODE("207","试用码扫码来源"),
    LIVE_PREVIEW_SUMMARY("225", "直播预览汇总"),
    COMMON_PAYMENT("230","客集集&客集集VIP用户付费后关注集客助手公众号"),
    CORP_EMPLOYEE_ACTIVATE("231", "企业版员工激活"),
    THIRD_PART_BIND("232", "第三方绑定"),
    AEON_LIFE_WX_WORK("233", "百年企微用户"),
    ;

    private String from;
    private String desc;

    SellerFromEnum(String from, String desc) {
        this.from = from;
        this.desc = desc;
    }

    /**
     * 获取所有需要发送绑定上下级关系客服消息类型
     */
    public static List<String> getNeedSendMsgTypes() {
        return Arrays.asList(POSTER_INVITE.getFrom(),
                CARD.getFrom(),
                SITE_SALE_QR.getFrom());
    }

    /**
     * 获取所有,上级可以非付费会员邀请类型
     */
    public static List<String> getOrdinaryUserDistributionTypes() {
        return Arrays.asList(VISITOR_PAYMENT.getFrom(),
                CARD.getFrom());
    }

    /**
     * 根据from处理获取对应枚举
     * @param from
     * @return
     */
    public static SellerFromEnum getByfrom(String from) {
        for (SellerFromEnum enumVal : SellerFromEnum.values()) {
            if (enumVal.getFrom().equals(from)) {
                return enumVal;
            }
        }
        return null;
    }

    public String getFrom() {
        return from;
    }

    public String getDesc() {
        return desc;
    }
}

==> kjy-center-api-1.1.21-sources.jar: cn/com/duiba/kjy/api/enums/seller/SellerFromEnum.java <==
package cn.com.duiba.kjy.api.enums.seller;

import java.util.Arrays;
import java.util.List;

/**
 * 销售员来源定义
 * @author zhanghuifeng
 * date 2019-06-25-16:27
 */
public enum SellerFromEnum {

    /**
     * 销售来源场景
     */
    NORMAL("0", "一般途径"),
    POSTER_INVITE("1", "海报邀请(普通邀请)"),
    CARD("2", "文章、午报、晚报换名片邀请(普通邀请)"),
    SITE_SALE_QR("3", "会销扫码（会销邀请）"),
    OUR_INSIDE_RECOMMEND("4", "公司内部销售推荐（只用作绩效记录，不做其它业务用途）"),
    WEEKLY_PUBLICATION("5", "周报中关注客集集"),
    VISITOR_PAYMENT("6", "访客转化为付费用户"),
    NOVICE_TASK("7", "新手任务邀请"),
    ACTIVATE_CODE("45", "激活码"),
    WX_MP_BASE_AUTH("46", "小程序授权"),
    PC_OFFICIAL_WEBSITE("77","官网"),
    VIP_NOT_SUBSCRIBE_VIP_ACCOUNT_PAGE("123", "付费代理人未关注vip公众号弹层二维码"),
    VIP_NOT_SUBSCRIBE_VIP_ACCOUNT_PUSH("124", "代理人通过蓝号推送的VIP公众号图片关注VIP公众号"),
    DAILY_CHANGE_CARD("126", "早报换名片邀请(普通邀请)"),
    VIDEO_CHANGE_CARD("137", "视频换名片邀请(普通邀请)"),
    CARTOON_CHANGE_CARD("127", "动画换名片邀请(普通邀请)"),
    GAME_ANSWER_CHANGE_CARD("135", "小游戏换名片邀请(普通邀请)"),
    GAME_LOTTERY_CHANGE_CARD("136", "抽奖工具换名片邀请(普通邀请)"),
    OTHER_CHANGE_CARD("134", "其他内容页换名片邀请(普通邀请)"),
    DAILY_CHANGE_MYPOINT("143", "早报换我的观点(换成我的观点弹层)"),
    PRE_INSTALL("159","会员预设"),
    VIP_TRANSFET("164", "会员转移"),
    OPEN_USER("165","第三方公众号用户"),
    MORNING_POSTER("166", "早安海报扫码来源"),
    EVENING_POSTER("167", "晚安海报扫码来源"),
    GUIDE_MORNING_CLOCK("168", "用户引导-早安打卡"),
    GUIDE_EVENING_CLOCK("169", "用户引导-晚安打卡"),
    GUIDE_EVERYDAY_QUESTION("170", "用户引导-每日一问(已更新)"),
    LIVE_VISITOR_MAP_COMPANY_NAME_LIST("194", "直播访客匹配架构名单成为代理人"),
    TRY_USE_CODE("207","试用码扫码来源"),
    LIVE_PREVIEW_SUMMARY("225", "直播预览汇总"),
    COMMON_PAYMENT("230","客集集&客集集VIP用户付费后关注集客助手公众号"),
    CORP_EMPLOYEE_ACTIVATE("231", "企业版员工激活"),
    THIRD_PART_BIND("232", "第三方绑定"),
    WX_WORK_ACTIVATE("233", "企微激活"),
    CLICK_TO_CHANGE_CARD("234", "「点击换成我的名片」转化"),
    ;

    private String from;
    private String desc;

    SellerFromEnum(String from, String desc) {
        this.from = from;
        this.desc = desc;
    }

    /**
     * 获取所有需要发送绑定上下级关系客服消息类型
     */
    public static List<String> getNeedSendMsgTypes() {
        return Arrays.asList(POSTER_INVITE.getFrom(),
                CARD.getFrom(),
                SITE_SALE_QR.getFrom());
    }

    /**
     * 获取所有,上级可以非付费会员邀请类型
     */
    public static List<String> getOrdinaryUserDistributionTypes() {
        return Arrays.asList(VISITOR_PAYMENT.getFrom(),
                CARD.getFrom());
    }

    /**
     * 根据from处理获取对应枚举
     * @param from
     * @return
     */
    public static SellerFromEnum getByfrom(String from) {
        for (SellerFromEnum enumVal : SellerFromEnum.values()) {
            if (enumVal.getFrom().equals(from)) {
                return enumVal;
            }
        }
        return null;
    }

    public String getFrom() {
        return from;
    }

    public String getDesc() {
        return desc;
    }
}
